@@ -1,6 +1,6 @@
 /*! \file */
 /* ************************************************************************
-* Copyright (C) 2023-2024 Advanced Micro Devices, Inc. All rights Reserved.
+* Copyright (C) 2023-2025 Advanced Micro Devices, Inc. All rights Reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
@@ -39,6 +39,7 @@
 #include "generic/rocsparse_sddmm.h"
 #include "generic/rocsparse_sparse_to_dense.h"
 #include "generic/rocsparse_sparse_to_sparse.h"
+#include "generic/rocsparse_spgeam.h"
 #include "generic/rocsparse_spgemm.h"
 #include "generic/rocsparse_spitsv.h"
 #include "generic/rocsparse_spmm.h"
@@ -46,5 +47,6 @@
 #include "generic/rocsparse_spsm.h"
 #include "generic/rocsparse_spsv.h"
 #include "generic/rocsparse_spvv.h"
+#include "generic/rocsparse_v2_spmv.h"
 
 #endif // ROCSPARSE_GENERIC_H
